@@ -8,10 +8,13 @@
 
 #include <KConfigGroup>
 #include <QObject>
-namespace KLDAP
+namespace KLDAPCore
+{
+class LdapServer;
+}
+namespace KLDAPWidgets
 {
 class LdapWidgetItem;
-class LdapServer;
 class LdapWidgetItemReadConfigServerJob : public QObject
 {
     Q_OBJECT
@@ -24,17 +27,17 @@ public:
     LdapWidgetItem *ldapWidgetItem() const;
     void setLdapWidgetItem(LdapWidgetItem *ldapWidgetItem);
 
-    Q_REQUIRED_RESULT int currentIndex() const;
+    [[nodiscard]] int currentIndex() const;
     void setCurrentIndex(int currentIndex);
 
-    Q_REQUIRED_RESULT bool active() const;
+    [[nodiscard]] bool active() const;
     void setActive(bool active);
 
-    Q_REQUIRED_RESULT KConfigGroup config() const;
+    [[nodiscard]] KConfigGroup config() const;
     void setConfig(const KConfigGroup &config);
 
 private:
-    void slotConfigLoaded(const KLDAP::LdapServer &server);
+    void slotConfigLoaded(const KLDAPCore::LdapServer &server);
     LdapWidgetItem *mLdapWidgetItem = nullptr;
     KConfigGroup mConfig;
     int mCurrentIndex = -1;
